#!/bin/bash
#-----------------------------------------------------------------------------------
# IPTables Personal Firewall Settings
#
# Written by Peter Quinn
# (C) Copyright 2004
#-----------------------------------------------------------------------------------

# Shell command variables
IPT='/sbin/iptables'
IFC='/sbin/ifconfig'
G='/bin/grep'
SED='/bin/sed'


#-----------------------------------------------------------------------------------
# START OF USER DEFINED INFORMATION
#
# Set interface variables
# If you have different ethernet interfaces than specified below then change them
# here, or if you do not have any of the following interfaces then comment them out
LOOPBACK=lo
INTERNET=eth0
# Comment out this line if you do not have a local home network
INTERNAL=eth1
# VMWare interfaces
VMNET1=vmnet1
VMNET8=vmnet8

# Set this IP address to your ISP's mail server
# eg.
# MAILSERVER=234.234.234.234
MAILSERVER=

# Known IP addresses of clients 
NETWORKUSER1=192.168.0.20
VMWARE=192.168.5.1

# Add trusted clients to this list that you would like to offer services to:
USERLIST="$NETWORKUSER1 $VMWARE"

# Open ports for the following programs...
DNS="no"
FTP="no"
HTTP="no"
SSH="no"
XSERVER="no"

COUNTER_STRIKE="yes"
UNREAL_TOURNAMENT="yes"
UT2004="yes"
QUAKEIII="yes"

BITTORRENT="yes"
EDONKEY="yes"
GIFT="yes"
TRACEROUTE="yes"
NMAP="yes"


# END OF USER DEFINED INFORMATION
#
#-----------------------------------------------------------------------------------

# Set up external interface variables
INTERNETIP="`$IFC $INTERNET | $G addr: | $SED 's/.*addr:\([^ ]*\) .*/\1/'`"
INTERNETBC="`$IFC $INTERNET | $G addr: | $SED 's/.*Bcast:\([^ ]*\) .*/\1/'`"
# Uncomment the following line if you have a pppoe connection
#INTERNETBC=255.255.255.255

# Set up internal interface variables
if [ $INTERNAL != "" ]
then
	INTERNALIP="`$IFC $INTERNAL | $G addr: | $SED 's/.*addr:\([^ ]*\) .*/\1/'`"
	INTERNALBC="`$IFC $INTERNAL | $G addr: | $SED 's/.*Bcast:\([^ ]*\) .*/\1/'`"
fi


#-----------------------------------------------------------------------------------
# set policies
$IPT -P	INPUT	DROP
$IPT -P	OUTPUT	DROP
$IPT -P FORWARD	DROP

# clear all chains
$IPT -F
$IPT -X


#-----------------------------------------------------------------------------------
# setup logging
$IPT -N DROPl	2> /dev/null
$IPT -A	DROPl	-j LOG --log-prefix 'DROPl:'
$IPT -A DROPl	-j DROP

$IPT -N HACKl	2> /dev/null
$IPT -A HACKl	-j LOG --log-prefix 'HACKl:'
$IPT -A HACKl	-j DROP

$IPT -N REJECTl	2> /dev/null
$IPT -A REJECTl	-j LOG --log-prefix 'REJECTl:'
$IPT -A REJECTl	-j REJECT

$IPT -N PINGl	2> /dev/null
$IPT -A PINGl	-j LOG --log-prefix 'PINGl:'
$IPT -A PINGl	-j DROP

$IPT -N VIRUSl	2> /dev/null
$IPT -A VIRUSl	-j LOG --log-prefix 'VIRUSl:'
$IPT -A VIRUSl	-j DROP

$IPT -N BLOCKl	2> /dev/null
$IPT -A BLOCKl	-j LOG --log-prefix 'BLOCKl:'
$IPT -A BLOCKl	-j DROP

$IPT -N ACCEPTl	2> /dev/null
$IPT -A ACCEPTl	-j LOG --log-prefix 'ACCEPTl:'
$IPT -A ACCEPTl	-j ACCEPT

$IPT -N HTTPl	2> /dev/null
$IPT -A HTTPl	-j LOG --log-prefix 'HTTPl:'
$IPT -A HTTPl	-j ACCEPT

$IPT -N DNSl	2> /dev/null
$IPT -A DNSl	-j LOG --log-prefix 'DNSl:'
$IPT -A DNSl	-j ACCEPT

$IPT -N SMTPl	2> /dev/null
$IPT -A SMTPl	-j LOG --log-prefix 'SMTPl:'
$IPT -A SMTPl	-j ACCEPT

$IPT -N ALERTl	2> /dev/null
$IPT -A ALERTl	-j LOG --log-prefix 'ALERTl:'
$IPT -A ALERTl	-j DROP


#-----------------------------------------------------------------------------------
# INPUT
#
# drop all broadcasts
#$IPT -A INPUT	-i $INTERNET -d $INTERNETBC -j DROP
#$IPT -A INPUT	-i $INTERNAL -d $INTERNALBC -j DROP
#$IPT -A OUTPUT	-o $INTERNET -d $INTERNETBC -j DROP
#$IPT -A OUTPUT	-o $INTERNAL -d $INTERNALBC -j DROP
#$IPT -A FORWARD	-o $INTERNET -d $INTERNETBC -j DROP
#$IPT -A FORWARD -o $INTERNAL -d $INTERNALBC -j DROP
$IPT -A INPUT	-i $INTERNET -d 255.255.255.255 -j DROP

# track all sendmail actions
$IPT -A OUTPUT	-o $INTERNET -p tcp --dport 25 -d ! $MAILSERVER/24 -j ALERTl
$IPT -A OUTPUT	-o $INTERNET -p tcp --dport 110 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p tcp --dport 25 -j ACCEPT
$IPT -A OUTPUT	-o $LOOPBACK -p tcp --dport 25 -j SMTPl

# deny identd instead of dropping it, for speed increase
$IPT -A INPUT	-i $INTERNET -p tcp --dport 113 -j DROP

# enable IP masquerading
$IPT -t nat -A POSTROUTING -o $INTERNET -j MASQUERADE

# enable Vmware networking
$IPT -A INPUT	-i $VMNET1 -j ACCEPT
$IPT -A INPUT	-i $VMNET8 -j ACCEPT
$IPT -A OUTPUT	-o $VMNET1 -j ACCEPT
$IPT -A OUTPUT	-o $VMNET8 -j ACCEPT
$IPT -A INPUT	-i $INTERNET -s $VMWARE/24 -j ACCEPT

# enable printer
$IPT -A INPUT	-s $INTERNETIP	-p udp --dport 631 -j ACCEPT


#-----------------------------------------------------------------------------------
# try to stop spammers from entering the system
$IPT -A INPUT	-i $INTERNET -d ! $INTERNETIP -j ALERTl


#-----------------------------------------------------------------------------------
# allow bittorrent
$IPT -A INPUT	-i $INTERNET -p tcp --dport 6881:6889 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p icmp --icmp-type 3 -j DROP
$IPT -A INPUT	-i $INTERNET -p tcp --dport 6881:6889 -j DROP

# edonkey / emule / amule
$IPT -A INPUT	-i $INTERNET -p tcp --dport 4662 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p udp --dport 4665 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p udp --dport 4672 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p udp --dport 4672 -j DROP
$IPT -A INPUT	-i $INTERNET -p udp --dport 4665 -j DROP
$IPT -A INPUT	-i $INTERNET -p tcp --dport 4662 -j DROP
$IPT -A OUTPUT	-o $INTERNET -p tcp --sport 4665 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --sport 4665 -j ACCEPT
PORTS="27017 4001 2026 4695 6666 5641 4352 5012 5005 2002 5226 5643 6569 10101 4990 3842 8800 4452 888 7639 4772 5773 4900 5842 7522 4669 5662 7315 11505 9561 3377 5840 5973 5880 4242 4661:4665 4346 6346 6891 4882 8886"
for i in $PORTS;
do
	$IPT -A OUTPUT	-o $INTERNET -p tcp --dport $i -j ACCEPT
done

# allow OpenFT:Gnutella:FastTrack
$IPT -A INPUT	-i $INTERNET -p tcp --dport 1214 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p udp --dport 1214 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p tcp --dport 1349 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p tcp --dport 1845 -m state --state RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p tcp --dport 2035 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p tcp --dport 2596 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p tcp --dport 3176 -m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A INPUT	-i $INTERNET -p tcp --dport 3667 -m state --state ESTABLISHED,RELATED -j ACCEPT


#-----------------------------------------------------------------------------------
# log all ping attempts
$IPT -A INPUT	-i $INTERNET -p icmp -j PINGl

# allow PING outwards to internet
$IPT -A INPUT	-i $INTERNET -p icmp --icmp-type echo-reply -j ACCEPT

# allow traceroute
$IPT -A INPUT	-i $INTERNET -p icmp --icmp-type 11 -m state --state ESTABLISHED,RELATED -j ACCEPT

# log anyone trying to ping us and drop their request
$IPT -A INPUT	-i $INTERNET -p icmp --icmp-type ! echo-reply -j PINGl


#-----------------------------------------------------------------------------------
# clients to block
#$IPT -A INPUT	-s $NETWORKUSER1 -j BLOCKl


#-----------------------------------------------------------------------------------
# stop MSN contacting hotmail
$IPT -A INPUT	-i $INTERNET -p udp -s 64.4.12.201 -j DROP
$IPT -A INPUT	-i $INTERNET -p tcp -s 207.68.178.16 -j DROP
# stop name servers
$IPT -A INPUT	-i $INTERNET -p tcp -s 10.50.64.1 -j DROP


#-----------------------------------------------------------------------------------
# block MSN spam
$IPT -A INPUT	-i $INTERNET -p udp --dport 1026:1029 -j DROP


#-----------------------------------------------------------------------------------
# for new clients connecting to this machine
# $IPT -A INPUT	-i $INTERNET -p tcp --dport 22 -j ACCEPT

# allow nmap -P0 to work properly
$IPT -A INPUT	-i $INTERNET -p tcp --dport 33200:33700 -j ACCEPT

# allow mail
$IPT -A INPUT	-i $LOOPBACK -p tcp --dport smtp -m state --state NEW -j ACCEPT


#-----------------------------------------------------------------------------------
# services offered to users
for i in $USERLIST;
do
	# allow DNS
	$IPT -A INPUT	-i $INTERNET -p udp --dport 53 -s $i -j DNSl

	# allow X
	$IPT -A INPUT	-i $INTERNET -p udp --dport 177 -s $i -m state --state NEW -j ACCEPT

	# allow HTTP
	$IPT -A INPUT	-i $INTERNET -p tcp --dport 8080 -s $i -m state --state NEW -j HTTPl

	# SSH connections
	$IPT -A INPUT	-i $INTERNET -p tcp --dport 22 -s $i -m state --state NEW -j ACCEPT

	# FTP
	$IPT -A INPUT	-i $INTERNET -p tcp --dport 21 -s $i -m state --state NEW -j ACCEPT
done

# allow all other internet & internal traffic to use HTTP daemon
#$IPT -A INPUT	-i $INTERNET -p tcp --dport 8080 -j HTTPl
#$IPT -A INPUT	-i $INTERNET -p tcp --dport 80 -j HTTPl
#if [ $INTERNAL != "" ]
#then
#	$IPT -A INPUT	-i $INTERNAL -p tcp --dport 8080 -j HTTPl
#	$IPT -A INPUT	-i $INTERNAL -p tcp --dport 80 -j HTTPl
#fi


#-----------------------------------------------------------------------------------
# log any other DNS request off of this machine
if [ $INTERNAL != "" ]
then
	$IPT -A INPUT	-i $INTERNAL -p udp --dport 53 -j DNSl
fi
$IPT -A INPUT	-i $INTERNET -p udp --dport 53 -j DROPl 

# Quake III
$IPT -A INPUT	-i $INTERNET -p udp --dport 27960 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --sport 27960 -j ACCEPT

# UT2004
$IPT -A INPUT	-i $INTERNET -p udp --dport 7787 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --sport 7787 -j ACCEPT

# Unreal Tournament
$IPT -A OUTPUT	-o $INTERNET -p udp --dport 7777 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --dport 7778 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --dport 7801 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --dport 8777:8788 -j ACCEPT
$IPT -A OUTPUT	-o $INTERNET -p udp --dport 8889 -j ACCEPT

# Half Life / Counter Strike
HL_UDP="27005 27015:27017 27025 27045 27065 27035 24000 24010 24020 24030 24120 24180 24210 24240 24200 24110 24170"
HL_TCP="27015 27020 27025 27030 27035 27040 27045 27050 27055 27060 27065"
for i in $HL_UDP;
do
	$IPT -A OUTPUT	-o $INTERNET -p udp --dport $i -j ACCEPT
done
for i in $HL_TCP;
do
	$IPT -A OUTPUT	-o $INTERNET -p tcp --dport $i -j ACCEPT
done


#-----------------------------------------------------------------------------------
# OUTPUT
#
TCPPORTS="21 80 110 1863 30000:65535"

for i in $TCPPORTS;
do
	$IPT -A OUTPUT	-o $INTERNET -p tcp --dport $i -j ACCEPT
done

#
$IPT -A OUTPUT	-o $INTERNET -p udp -d $INTERNETBC -j DROP
#$IPT -A OUTPUT	-o $INTERNET -p udp --dport 53 -j DNSl

# for speed purposes allow everything to go out to the internet
$IPT -A OUTPUT	-o $INTERNET -j ACCEPT


#-----------------------------------------------------------------------------------
# allow local loopback interface
$IPT -A INPUT	-i $LOOPBACK -j ACCEPT
$IPT -A OUTPUT	-o $LOOPBACK -j ACCEPT
$IPT -A FORWARD	-i $LOOPBACK -j ACCEPT
$IPT -A FORWARD	-o $LOOPBACK -j ACCEPT

# allow local network
if [ $INTERNAL != "" ]
then
	$IPT -A INPUT	-i $INTERNAL -j ACCEPT
	$IPT -A OUTPUT	-o $INTERNAL -j ACCEPT
	$IPT -A FORWARD	-o $INTERNAL -j ACCEPT
	$IPT -A FORWARD	-i $INTERNAL -j ACCEPT
fi


#-----------------------------------------------------------------------------------
# stop hackers
COMBLOCK="0:1 13 98 137:139 161:162 445 1214 1434 1999 2049 3049 4329 6346 8008 9898 40638 53050 65535"
TCPBLOCK="$COMBLOCK 98 137 512:515 559 1023 1025 1036 1043 1045 1080 2535 2745 3127 3410 5000 5554 6000:6009 6112 6129 20257 21525 27374 65506"
UDPBLOCK="$COMBLOCK 161:162 520 123 517:518 1427 9000"
for i in $TCPBLOCK;
do
	$IPT -A INPUT   -p tcp --dport $i  -j VIRUSl
	$IPT -A OUTPUT  -p tcp --dport $i  -j VIRUSl
	$IPT -A FORWARD -p tcp --dport $i  -j VIRUSl
done

for i in $UDPBLOCK;
do
	$IPT -A INPUT   -p udp --dport $i  -j VIRUSl
	$IPT -A OUTPUT  -p udp --dport $i  -j VIRUSl
	$IPT -A FORWARD -p udp --dport $i  -j VIRUSl
done


#-----------------------------------------------------------------------------------
# log all attempted hacks into the system of known ports used for access
ALLHACKS="68 111 3128 8000 33791"
UDPHACKS="$ALLHACKS 177"
TCPHACKS="$ALLHACKS 21 22 23 25 79 110 1433 3389 4899 5631 8080 10080 12345"

for i in $UDPHACKS;
do
	$IPT -A INPUT	-p udp --dport $i -m state --state NEW -j HACKl
	$IPT -A OUTPUT	-p udp --dport $i -m state --state NEW -j HACKl
	$IPT -A FORWARD	-p udp --dport $i -m state --state NEW -j HACKl
done

for i in $TCPHACKS;
do
	$IPT -A INPUT	-p tcp --dport $i -m state --state NEW -j HACKl
	$IPT -A OUTPUT	-p tcp --dport $i -m state --state NEW -j HACKl
	$IPT -A FORWARD	-p tcp --dport $i -m state --state NEW -j HACKl
done


#-----------------------------------------------------------------------------------
# ports used by FTP & other internet applications
# you can comment this line if you feel it is unsafe
$IPT -A INPUT	-p tcp --dport 30000:65535 -j ACCEPT

# accept all data coming in and out already connected
$IPT -A INPUT	-m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A OUTPUT	-m state --state ESTABLISHED,RELATED -j ACCEPT
$IPT -A FORWARD	-m state --state ESTABLISHED,RELATED -j ACCEPT

# log any connection attempts to ports that are not on our known ports list
if [ $INTERNAL != "" ]
then
	$IPT -A INPUT	-i $INTERNAL -j DROPl
fi
$IPT -A INPUT	-i $INTERNET -m state --state NEW -j DROPl
$IPT -A OUTPUT	-o $INTERNET -j DROPl


#-----------------------------------------------------------------------------------
# log successful completion of firewall rules
DATE=`date`
echo "New firewall rules activated by user $USER at $DATE on $HOSTNAME."
echo "$DATE $HOSTNAME: New firewall rules are now activated by user $USER." >> "/var/log/messages"


#-----------------------------------------------------------------------------------


