#----------------------------------------------------------------------------------#
#
# HYPERTAIL DISPLAY METHODS
#
# FILE:			hypertail.script
# AUTHOR:		Peter Quinn
# DATE:			02.02.2005
# VERSION:		1.00
#
# DESCRIPTION:	Main methods used for displaying the HyperTail to the screen.
#
#----------------------------------------------------------------------------------#

TEXT		= 0
ORIGINAL	= 1
INDEX		= 2
COLOUR		= 3
LINENUM		= 4

lines		= []

con_status	= False


#----------------------------------------------------------------------------------#
#
#
#
def arrowover(obj):

	if scrollarrows:
		if con_status:
			winobj = console
		else:
			winobj = buffer
			
		if obj.id == "arrowupgroup":
			if winobj.window_pos == 0:
				return

		else:
			if winobj.window_pos + winobj.window_size == winobj.size:
				return
				
		obj.bg_color = scrollcolour


#
#
#
def arrowout(obj):

	global constatus
	
	if scrollarrows:
		if con_status:
			winobj = console
		else:
			winobj = buffer
			
		if obj.id == "arrowupgroup":
			if winobj.window_pos == 0:
				return

		else:
			if winobj.window_pos + winobj.window_size == winobj.size:
				return

		obj.bg_color = "#00000000"


#
#
#
def dragdrop(obj):

	global file_list, cmd_list
	
	files = obj.event.files
	for i in range(len(files)):
		reg.search = ("file://(.*)", files[i])
		Prefs.file.value = reg.result.group(1)
		add_file(0)


#
# Mouse-over method
#
def enter(obj):

	global lines, con_status
	
	if not con_status and logging:
	
		if len(lines) > 0:
			n = lines[obj.index_path[0]][2]

			if cmd_list[n][0]:
				obj.color = mscolour


#
# Mouse-out method
#
def leave(obj):

	global lines, con_status

	if not con_status and logging:
		n = obj.index_path[0]

		if len(lines) > 0:
			if lines[n]:
				obj.color = lines[n][COLOUR]


#
# Scroll desklet display up or down
#
def scroll(value):

	global con_status
	
	if not con_status:
		if (value == 0):
			buffer.window_pos -= 1
		else:
			buffer.window_pos += 1
			
		refresh_display(1)
	
	else:
		if (value == 0):
			console.window_pos -= 1
		else:
			console.window_pos += 1

		refresh_console()



#
#
#
def click(value):

	global con_status, con_done
	
	if logging:
		if con_status and con_done:
			con_status = False
			Dsp.consolebody.visible = False
			con_done = False
			refresh_arrows()

		elif not con_status:
			n = lines[value.index_path[0]][2]

			if cmd_list[n][0]:
				leave(value)
				(action, console, command, parameter) = cmd_list[lines[value.index_path[0]][2]]

				if parameter == "":
					parameter = lines[value.index_path[0]][5]
					n = -1
					tail.execute = (command, parameter, n)

				if console:
					con_status = True
					Dsp.consolebody.visible = True
					Dsp.consolebody.on_click = "click(None)"
					
					reg.search = (parameter, lines[value.index_path[0]][0])
					if reg.result:
						con_execute((command, reg.result.group(1), n))
					else:
						con_execute((command, "", n))


#----------------------------------------------------------------------------------#
#
# Called when a file has changed
#
def refresh(value):

	buffer.write = tail.buffer

	refresh_display(1)


#
# Refresh desklet display
#
def refresh_display(value):

	global lines

	if wordwrapping:
		wrap.size			= buffer.size
		wrap.window_size	= buffer.window_size
		wrap.window_pos		= buffer.window_pos
		wrap.cursor			= buffer.cursor

		tmp = buffer.read_all

		for i in range(len(tmp)):
			(txt, original, index, colour, lineno, path) = tmp[i]
			
			while txt:
				line = txt[:wraplength]
				wrap.write = [(line, original, index, colour, lineno, path)]
				txt = txt[wraplength:]

		lines = wrap.read
		
	else:
		lines = buffer.read

	n = tail.get_lines
	
	if n > 0:
		Dsp.plotter.value = n
		Dsp.updated2.value = "%.2d:%.2d.%.2d" % (time.time[0], time.time[1], time.time[2])

	for i in range(len(lines)):
		Dsp.line[i].font	= font
		Dsp.line[i].color	= lines[i][COLOUR]
		Dsp.line[i].value	= lines[i][TEXT]

	refresh_arrows()


#
# Refresh entire buffer to reflect changes
#
def refresh_buffer():

	try:
		buffer.cursor	= 0
		tail.buffer		= buffer.read_all
		buffer.write	= tail.buffer

		refresh_display(1)
	except:
		pass


#
#
#
def refresh_arrows():

	if scrollarrows:
		if con_status:
			winobj = console
		else:
			winobj = buffer

		if winobj.window_pos == 0:
			Dsp.arrowup.visible			= False
			Dsp.arrowupgroup.bg_color	= "#00000000"
			
		else:
			Dsp.arrowup.visible			= True

		if winobj.window_pos + winobj.window_size == winobj.size:
			Dsp.arrowdown.visible		= False
			Dsp.arrowdowngroup.bg_color	= "#00000000"
			
		else:
			Dsp.arrowdown.visible		= True

		pos = (width / 2) - 4

		Dsp.arrowup.x	= Unit(pos, PX)
		Dsp.arrowdown.x	= Unit(pos, PX)

			
#----------------------------------------------------------------------------------#

