#----------------------------------------------------------------------------------#
#
# HYPERTAIL PREFERENCES SCRIPT
#
# FILE:			prefs.py
# AUTHOR:		Peter Quinn
# DATE:			10.02.2005
# VERSION:		1.00
#
# DESCRIPTION:	Main preferences script for HyperTail.
#
#----------------------------------------------------------------------------------#

header			= True
seperator		= True
plotter			= True
infofont		= "Sans 7"
infocolour		= "#FFFF00"
valuefont		= "Sans 7"
valuecolour		= "#FFFFFF"

scrollarrows	= False
scrollcolour	= "#FFFFFF20"

width			= 250
windowsize		= 20
buffersize		= 40
font			= "Monospace 7.5"
mscolour		= "#FFFFFF"
filename		= 0
wordwrapping	= False
wraplength		= 40
update			= 600
linenumbers		= False
digits			= 4
padding			= "none"
suppress		= False


#----------------------------------------------------------------------------------#
#
# PREFERENCES CALLBACK:
#
#
def prefs_cb(key, value):

	if		key == "buffersize":	set_buffersize(value)
	elif	key == "windowsize":	set_windowsize(value)
	elif	key == "font":			set_font(value)
	elif	key == "mscolour":		set_mscolour(value)
	elif	key == "filename":		set_filename(value)
	elif	key == "update":		set_update(value)
	elif	key == "redraw":		set_redraw(value)
	elif	key == "wordwrapping":	set_wordwrap(value)
	elif	key == "wraplength":	set_wraplength(value)
	elif	key == "suppress":		set_suppress(value)
	elif	key == "linenumbers":	set_linenumbers(value)
	elif	key == "digits":		set_digits(value)
	elif	key == "padding":		set_padding(value)
	elif	key == "header":		set_header(value)
	elif	key == "plotter":		set_plotter(value)
	elif	key == "infofont":		set_infofont(value)
	elif	key == "infocolour":	set_infocolour(value)
	elif	key == "valuefont":		set_valuefont(value)
	elif	key == "valuecolour":	set_valuecolour(value)
	elif	key == "scrollarrows":	set_scrollarrows(value)
	elif	key == "scrollcolour":	set_scrollcolour(value)
	
	regexp_prefs(key, value)
	file_prefs(key, value)
	console_prefs(key, value)
	theme_prefs(key, value)


#----------------------------------------------------------------------------------#
#
#
#
# Sets the height of the visible region of the buffer.
#
def set_windowsize(value):

	windowsize = value
	buffer.window_size	= windowsize
	buffer.window_pos	= buffersize

	Dsp.log.length = windowsize

	if windowsize > buffersize:
		Prefs.buffersize.min	= windowsize
		Prefs.buffersize.value	= windowsize
		set_buffersize(windowsize)
	else:
		Prefs.buffersize.min = windowsize
		refresh_buffer()

	Prefs.con_height.max = windowsize


#
# Sets the size of the scroll back buffer.
#
def set_buffersize(value):

	buffersize			= value
	buffer.size			= buffersize
	buffer.window_pos	= buffersize

	refresh_buffer()


#
#
#
def set_scrollarrows(value):

	scrollarrows = value

	Prefs.scrollcolour.enabled	= scrollarrows
	Dsp.arrowupgroup.visible	= scrollarrows
	Dsp.arrowdowngroup.visible	= scrollarrows

	refresh_arrows()


#
#
#
def set_scrollcolour(value):

	scrollcolour = value


#----------------------------------------------------------------------------------#
#
#
#
# Sets the font display.
#
def set_font(value):
	
	font = value

	for i in range(windowsize):
		Dsp.line[i].font = value


#
# Turns display of filenames on/off.
#
def set_filename(value):

	tail.filenames = value

	refresh_buffer()


#
# Sets the interval time between file polls.
#
def set_update(value):

	update = value
	
	tail.update = value


#
# Sets the mouse-over colour.
#
def set_mscolour(value):

	mscolour = value


#
# Turns word wrapping on/off.
#
def set_wordwrap(value):

	wordwrapping = value
	Prefs.wraplength.enabled = wordwrapping

	refresh_buffer()


#
# Sets the length of the word wrap.
#
def set_wraplength(value):

	wraplength = value

	refresh_buffer()


#
# Sets on/off of empty lines.
#
def set_suppress(value):

	tail.suppress = value


#
#
#
def set_linenumbers(value):

	linenumbers = value
	tail.line_numbers = linenumbers

	Prefs.digits.enabled	= value
	Prefs.padding.enabled	= value

	refresh_buffer()


#
# Sets the amount of digits
#
def set_digits(value):

	digits = value
	tail.digits = digits

	refresh_buffer()


#
#
#
def set_padding(value):

	padding = value
	tail.padding = padding

	refresh_buffer()
	

#----------------------------------------------------------------------------------#
#
#
#
def set_header(value):

	header = value

	Dsp.header.visible				= header
	Prefs.iconfile.enabled			= header
	Prefs.iconscale.enabled			= header
	Prefs.titlefont.enabled			= header
	Prefs.titlecolour.enabled		= header
	Prefs.versionfont.enabled		= header
	Prefs.versioncolour.enabled		= header
	Prefs.infofont.enabled			= header
	Prefs.infocolour.enabled		= header
	Prefs.valuefont.enabled			= header
	Prefs.valuecolour.enabled		= header
	Prefs.plotter.enabled			= header
	Prefs.seperatorcolour.enabled	= header

	if not plotter and header:
		Prefs.plottercolour.enabled	= False
	else:
		Prefs.plottercolour.enabled	= header


def set_infofont(value):

	infofont = value

	Dsp.watches1.font	= infofont
	Dsp.updated1.font	= infofont
	
	
def set_infocolour(value):

	infocolour = value

	Dsp.watches1.color	= infocolour
	Dsp.updated1.color	= infocolour
	
	
def set_valuefont(value):

	valuefont = value

	Dsp.watches2.font	= valuefont
	Dsp.updated2.font	= valuefont
	
	
def set_valuecolour(value):

	valuecolour = value

	Dsp.watches2.color	= valuecolour
	Dsp.updated2.color	= valuecolour

	
def set_plotter(value):

	plotter = value

	Dsp.plotter.visible			= plotter
	Prefs.plottercolour.enabled	= plotter


#----------------------------------------------------------------------------------#

set_wordwrap(wordwrapping)
set_linenumbers(linenumbers)

